@@ -12,13 +12,12 @@ fn main() -> Result<()> {
         .filter_level(LevelFilter::Debug)
         .init();
 
-    let (mqtt_client, mqtt_worker) = MqttClientBuilder::new()
-        .set_mqtt_broker(MQTT_BROKER.parse()?)
-        .set_on_connected_callback(on_mqtt_connected)
-        .set_on_message_callback(on_mqtt_message)
-        .set_client_id("example-client")
-        .subscribe("client/example", QoS::AtLeastOnce)
-        .build()?;
+    let (mqtt_client, mqtt_worker) = MqttClientBuilder::new(MQTT_BROKER.parse()?)
+        .on_connected_callback(on_mqtt_connected)
+        .on_message_callback(on_mqtt_message)
+        .client_id("example-client")
+        .subscribe("client/example/receive", QoS::AtLeastOnce)
+        .build();
 
     let worker_runtime = runtime::Builder::new_multi_thread()
         .enable_all()
@@ -33,7 +32,7 @@ fn main() -> Result<()> {
         let message = serde_json::json!({ "counter": counter });
 
         mqtt_client.publish_json(
-            "client/example",
+            "client/example/publish",
             &message,
             false,
             QoS::AtLeastOnce,
@@ -44,7 +43,7 @@ fn main() -> Result<()> {
 
         counter += 1;
 
-        thread::sleep(Duration::from_micros(10));
+        thread::sleep(Duration::from_secs(1));
     }
 }
 
