@@ -12,11 +12,10 @@ fn main() -> Result<()> {
         .filter_level(LevelFilter::Debug)
         .init();
 
-    let (mqtt_client, mqtt_worker) = MqttClientBuilder::new()
-        .set_mqtt_broker(MQTT_BROKER.parse()?)
-        .set_on_connected_callback(on_mqtt_connected)
-        .set_client_id("example-client")
-        .build()?;
+    let (mqtt_client, mqtt_worker) = MqttClientBuilder::new(MQTT_BROKER.parse()?)
+        .on_connected_callback(on_mqtt_connected)
+        .client_id("example-client")
+        .build();
 
     let worker_runtime = runtime::Builder::new_multi_thread()
         .enable_all()
@@ -42,7 +41,7 @@ fn main() -> Result<()> {
 
         counter += 1;
 
-        std::thread::sleep(Duration::from_micros(10));
+        std::thread::sleep(Duration::from_secs(1));
     }
 }
 
