@@ -1,5 +1,3 @@
-use std::time::Duration;
-
 use anyhow::Result;
 use gmqtt_client::{Message, MqttClientBuilder, QoS};
 use log::{info, LevelFilter};
@@ -12,12 +10,11 @@ fn main() -> Result<()> {
         .filter_level(LevelFilter::Debug)
         .init();
 
-    let (_, mqtt_worker) = MqttClientBuilder::new()
-        .set_mqtt_broker(MQTT_BROKER.parse()?)
-        .set_on_connected_callback(on_mqtt_connected)
-        .set_on_message_callback(on_mqtt_message)
+    let (_, mqtt_worker) = MqttClientBuilder::new(MQTT_BROKER.parse()?)
+        .on_connected_callback(on_mqtt_connected)
+        .on_message_callback(on_mqtt_message)
         .subscribe("client/example/pubsub", QoS::AtLeastOnce)
-        .build()?;
+        .build();
 
     let worker_runtime = runtime::Builder::new_multi_thread()
         .enable_all()
@@ -26,9 +23,8 @@ fn main() -> Result<()> {
 
     worker_runtime.spawn(async { mqtt_worker.run().await });
 
-    loop {
-        std::thread::sleep(Duration::from_secs(10));
-    }
+    std::thread::park();
+    Ok(())
 }
 
 fn on_mqtt_connected() {
