@@ -7,7 +7,7 @@ pub type OnMessageCallback = dyn Fn(&Message) + Send + Sync + 'static;
 pub type OnMessageOwnedCallback = dyn Fn(Message, Instant) + Send + 'static;
 pub type OnConnectedCallback = dyn Fn() + Send + Sync + 'static;
 
-pub struct MqttClientConfig {
+pub(crate) struct MqttClientConfig {
     pub client_id: String,
     pub subscribe_filters: Vec<SubscribeFilter>,
     pub on_message_callback: Option<Box<OnMessageCallback>>,
